@@ -1,12 +1,11 @@
 use std::fs;
-use std::fs::{ReadDir,DirEntry,File};
-use std::io::{Error,ErrorKind};
+use std::io::{Error};
 use std::path::Path;
-use crate::bro;
 
 /// The remove_dir funtion will remove a directory only of its empty.
 /// Its operation is safe. This fn should be used normally unless brute removal is required 
-/// Example :: ```
+/// Example :: 
+/// ```rust
 /// let p_dir = brown::create_dir("parent");
 /// let outcome = brown::remove_dir("parent");
 ///  assert!(outcome.is_ok());
