@@ -1,5 +1,4 @@
-use brown;
-use brown::tasks;
+use brown as bro;
 
 #[cfg(test)]
 #[test]
@@ -14,8 +13,8 @@ fn use_fn(){
                 "site/images", 
                 "hulkfolder/templates" ,
             ];
-let a = tasks::create_dir_structure::
-run(&paths_list);
+let a = bro::create_dir_structure
+(&paths_list);
 assert!(a.is_ok());
     //====== tests
     assert_eq!(true,brown::path_exists("./data"));
@@ -23,10 +22,10 @@ assert!(a.is_ok());
     assert_eq!(true,brown::path_exists("./site/images"));
     assert_eq!(true,brown::path_exists("./hulkfolder/templates")); 
     
-    brown::remove_dir_brute("./data");
-    brown::remove_dir_brute("./data_with");
-    brown::remove_dir_brute("./site/images");
-    brown::remove_dir_brute("./hulkfolder/templates"); 
-    brown::remove_dir_brute("./hulkfolder"); 
+    let _ = brown::remove_dir_brute("./data");
+    let _ = brown::remove_dir_brute("./data_with");
+    let _ = brown::remove_dir_brute("./site/images");
+    let _ = brown::remove_dir_brute("./hulkfolder/templates"); 
+    let _ = brown::remove_dir_brute("./hulkfolder"); 
      
 }
\ No newline at end of file
